@@ -9,6 +9,9 @@ from .plugin_sas import *
 from .plugin_relap5 import *
 from .plugin_mcnp import *
 from .plugin_serpent import *
+from .plugin_abce import *
+from .plugin_dakota import *
+from .results import *
 from .template import *
 from .parameters import *
 from .database import *
@@ -16,4 +19,4 @@ from .database import *
 # This allows a user to write watts.Quantity
 from astropy.units import Quantity
 
-__version__ = '0.3.0'
+__version__ = '0.4.0'
